MediaFrame

Struct MediaFrame 

pub struct MediaFrame { /* private fields */ }
A an abstraction of a media frame owning an internal buffer. Can optionally have meta data (e.g. a header) associated to it.

Implementations

Source

impl MediaFrame

pub fn new<P>(frame_counter: &mut impl FrameCounter, payload: P) -> Self
where P: AsRef<[u8]>,

Creates a new media frame by copying the data of a payload buffer and assigning it the given frame count.

pub fn with_meta_data<P, M>( frame_counter: &mut impl FrameCounter, payload: P, meta_data: M, ) -> Self
where P: AsRef<[u8]>, M: AsRef<[u8]>,

Creates a new media frame and assigns it the given frame count. Payload and meta data are copied into an internal buffer.

pub fn meta_data(&self) -> &[u8]

Meta data associated with this media frame

pub fn payload(&self) -> &[u8]

Payload of this media frame

pub fn counter(&self) -> Counter

Frame count for the Sframe scheme associated to this media frame

pub fn encrypt<A, D>(&self, key: &EncryptionKey<A, D>) -> Result<EncryptedFrame>
where A: AeadEncrypt<Secret = D::Secret>, D: KeyDerivation,

Encrypts the media frame with the sframe key according to RFC 9605 4.4.3. Dynamically allocates memory for the resulting EncryptedFrame. The associated meta data is not encrypted but considered for the authentication tag. Returns an crate::error::SframeError when encryption fails

pub fn encrypt_into<'obuf, A, D>( &self, key: &EncryptionKey<A, D>, buffer: &'obuf mut impl FrameBuffer, ) -> Result<EncryptedFrameView<'obuf>>
where A: AeadEncrypt<Secret = D::Secret>, D: KeyDerivation,

Encrypts the media frame with the sframe key according to RFC 9605 4.4.3 and stores the result into the provided buffer. An EncryptedFrameView on the buffer is returned on success. The associated meta data is not encrypted but considered for the authentication tag. Returns an crate::error::SframeError when encryption fails.