pub struct MonotonicCounter { /* private fields */ }Expand description
A simple counter that increases by one for each call to next() up to a fixed limit. It never
wraps around, reusing a counter value would break the uniqueness required by
FrameCounter - instead it is exhausted after the limit was reached, see
MonotonicCounter::is_exhausted. Per Default the limit is u64::MAX.
Implementations
Sourceimpl MonotonicCounter
impl MonotonicCounter
Sourcepub fn new(max_counter: u64) -> Self
pub fn new(max_counter: u64) -> Self
Creates a new counter which is exhausted after max_counter was returned.
Sourcepub fn with_start_value(start_value: u64, max_counter: u64) -> Self
pub fn with_start_value(start_value: u64, max_counter: u64) -> Self
Creates a new counter with a start value which is exhausted after max_counter was
returned.
Sourcepub fn is_exhausted(&self) -> bool
pub fn is_exhausted(&self) -> bool
Returns true if all counter values were used up, i.e. the next call to
FrameCounter::next will panic.