pub type DecryptionKey = DecryptionKey<Aead, Kdf>;Expand description
Decryption key using the crypto backend selected via feature flags.
Aliased Type
pub struct DecryptionKey { /* private fields */ }pub type DecryptionKey = DecryptionKey<Aead, Kdf>;Decryption key using the crypto backend selected via feature flags.
pub struct DecryptionKey { /* private fields */ }